==> fbat_1.0.0.tar.gz: fbat/R/checkAlleles.R <==
## check number of alleles
checkAlleles <- function(
                         ped, 
                         columns=c("family", "pid", "father", "mother", 
                                   "sex", "affected")
                         )
{
  tmp <- checkColumn(ped, columns)
  ped<-tmp$ped
  columns<-tmp$columns

  tmp <- getAlleles(ped, columns)
  
  alleles <- tmp$alleles # 'alleles' is a concatinated vector of marker
                         ##  alleles for all markers.
  nAllele <- tmp$nAllele # number of alleles for each marker

  ## check if number of alleles for a marker is greater than 2
  pos <- which(nAllele>2)
  if(length(pos)>0)
    {
      markerNames <- getMarkerNames(ped, columns)
      stop("Markers ", paste("`", markerNames[pos], "'", sep=", "), " ",
           "have more than 2 alleles.  Only bi-allelic markers ", 
           "are currently supported.")
    }

  invisible(
            list(alleles=alleles, 
                 nAllele=nAllele)
            )

}

## get alleles of markers from pedigrees
getAlleles <- function(
                       ped, 
                       columns=c("family", "pid", "father", "mother", 
                                 "sex", "affected")
                       )
{

  len <- length(columns)
  ped <- as.matrix(ped)
  nr <- nrow(ped)
  nr2 <- nr*2
  nc <- ncol(ped)
  nMarker <- (nc-len)/2
  ped2 <- ped[, -c(1:len)]
  ped2 <- matrix(ped2, nrow=nr2, byrow=F)

  # obtain unique alleles for each marker
  alleles<-apply(ped2, 2, sortUnique)
  if(is.list(alleles)==TRUE)
  { nAllele<-sapply(alleles, length) 
    alleles<-unlist(alleles)
    nAllele<-unlist(nAllele)
  }
  else { 
    nAllele<-apply(alleles, 2, length) 
    alleles<-as.vector(alleles)
  }
  # alleles may contain zero. So we need to delete them
  pos<-which(alleles==0)
  if(length(pos)>0)
  { alleles<-alleles[-pos] }

  tmpFun<-function(x)
  { xx<-unique(x)
    pos<-which(xx==0)
    return(length(pos))
  }

  # alleles may contain zero
  nZero<-apply(ped2, 2, tmpFun)
  # true number of alleles for each marker
  nAllele<-nAllele-nZero
  
  invisible(
            list(alleles=alleles,
                 nAllele=nAllele)
            )
}

==> fbat_1.10.0.tar.gz: fbat/R/checkAlleles.R <==
## check number of alleles
checkAlleles <- function( pedObj )
{
  pedObj <- checkColumn(pedObj)
  ped<-pedObj$ped
  columns<-pedObj$columns
  markerNames<-pedObj$markerNames

  tmp <- getAlleles(pedObj)
  
  alleles <- tmp$alleles # 'alleles' is a concatinated vector of marker
                         ##  alleles for all markers.
  nAllele <- tmp$nAllele # number of alleles for each marker

  ## check if number of alleles for a marker is greater than 2
  pos <- which(nAllele>2)
  if(length(pos)>0)
    {
      stop("Markers ", paste("`", markerNames[pos], "'", sep=", "), " ",
           "have more than 2 alleles.  Only bi-allelic markers ", 
           "are currently supported.")
    }

  invisible(
            list(alleles=alleles, 
                 nAllele=nAllele)
            )

}

## get alleles of markers from pedigrees
getAlleles <- function( pedObj )
{
  pedObj <- checkColumn(pedObj)
  ped<-pedObj$ped
  columns<-pedObj$columns

  len <- length(columns)
  ped <- as.matrix(ped)
  nr <- nrow(ped)
  nr2 <- nr*2
  nc <- ncol(ped)
  ped2 <- ped[, -c(1:len), drop=FALSE]
  ped2 <- matrix(ped2, nrow=nr2, byrow=F)

  # obtain unique alleles for each marker
  alleles<-apply(ped2, 2, sortUnique)
  if(is.list(alleles)==TRUE)
  { nAllele<-sapply(alleles, length) 
    alleles<-unlist(alleles)
    nAllele<-unlist(nAllele)
  }
  else { 
    nAllele<-apply(alleles, 2, length) 
    alleles<-as.vector(alleles)
  }
  # alleles may contain zero. So we need to delete them
  pos<-which(alleles==0)
  if(length(pos)>0)
  { alleles<-alleles[-pos] }

  tmpFun<-function(x)
  { xx<-unique(x)
    pos<-which(xx==0)
    return(length(pos))
  }

  # alleles may contain zero
  nZero<-apply(ped2, 2, tmpFun)
  # true number of alleles for each marker
  nAllele<-nAllele-nZero
  
  invisible(
            list(alleles=alleles,
                 nAllele=nAllele)
            )
}
